##  Overview
You can create automations that run custom scripts to update fact sheet fields or make calls to SAP LeanIX APIs. Scripts run in a secure environment in SAP LeanIX, eliminating the need for third-party tools. When a triggering event occurs, an automation checks the conditions you specify. If all conditions are met, the script runs and initiates the actions you define. You can also include other actions in the automation flow in addition to the script.
You define the script logic using JavaScript in a script editor directly in SAP LeanIX. The script editor provides the following resources to help you create code more efficiently:
  * Predefined code snippets for common scenarios
  * The IDs of tags configured in your workspace


![Script Editor in Automations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio87b3a44d92f94261a36a9a453e8c9b75_LowRes.png)
Script Editor in Automations
